@@ -374,6 +374,8 @@ entry_added (IndicatorObject * io, IndicatorObjectEntry * entry, GtkWidget * men
   GtkWidget * box = (packdirection == GTK_PACK_DIRECTION_LTR) ?
       gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 3) : gtk_box_new(GTK_ORIENTATION_VERTICAL, 3);
 
+  gtk_widget_add_events(GTK_WIDGET(menuitem), GDK_SCROLL_MASK);
+
   g_object_set_data (G_OBJECT (menuitem), MENU_DATA_BOX, box);
   g_object_set_data(G_OBJECT(menuitem), MENU_DATA_INDICATOR_ENTRY,  entry);
   g_object_set_data(G_OBJECT(menuitem), MENU_DATA_INDICATOR_OBJECT, io);
@@ -536,10 +538,10 @@ menu_show (IndicatorObject * io, IndicatorObjectEntry * entry,
 
   if (entry == NULL) {
     /* Close any open menus instead of opening one */
+    GList * l;
     GList * entries = indicator_object_get_entries(io);
-    GList * entry = NULL;
-    for (entry = entries; entry != NULL; entry = g_list_next(entry)) {
-      IndicatorObjectEntry * entrydata = (IndicatorObjectEntry *)entry->data;
+    for (l = entries; l != NULL; l = g_list_next(entry)) {
+      IndicatorObjectEntry * entrydata = l->data;
       gtk_menu_popdown(entrydata->menu);
     }
     g_list_free(entries);
@@ -592,7 +594,7 @@ load_module (const gchar * name, GtkWidget * menubar)
   g_free(fullpath);
 
   /* Set the environment it's in */
-  indicator_object_set_environment(io, (const GStrv)indicator_env);
+  indicator_object_set_environment(io, (GStrv)indicator_env);
 
   /* Attach the 'name' to the object */
   g_object_set_data_full(G_OBJECT(io), IO_DATA_NAME, g_strdup(name), g_free);
@@ -839,7 +841,6 @@ applet_fill_cb (PanelApplet * applet, const gchar * iid G_GNUC_UNUSED,
   GtkWidget *menubar;
   gint indicators_loaded = 0;
   GtkActionGroup *action_group;
-  GError *error = NULL;
 
 #ifdef INDICATOR_APPLET_SESSION
   /* check if we are running stracciatella session */
